@@ -101,6 +101,7 @@ def main():
     argparser = argparse.ArgumentParser('irco-import')
     argparser.add_argument('-v', '--verbose', action='store_true')
     argparser.add_argument('-i', '--input-format', choices=pipelines)
+    argparser.add_argument('-e', '--encoding', default='utf8')
     argparser.add_argument('source', nargs='+')
     argparser.add_argument('database')
 
@@ -118,7 +119,7 @@ def main():
 
     log.info('arguments_parsed', args=args)
 
-    pipeline = pipelines[args.input_format]
+    pipeline = pipelines[args.input_format](encoding=args.encoding)
     engine = create_engine(args.database, echo=args.verbose)
     Session = sessionmaker(bind=engine)
 
